#-------------------
# Figure 1
#-------------------
gamma1=1
xi1=1
up=20
#Baseline survival function
curve((x/xi1)^(-gamma1),xi1,up,xlim=c(0,up),
      xlab="x",ylim=c(0,1),lwd=2,lty="solid",
      ylab=expression(paste(S(x)==1/x,",   ",x>=1))
      )

Median=expression(paste("Median =",S^{-1}, "(1/2) = 2"))
legend(1,0.9,Median,text.col="blue",bty="n")
segments(x0=0,y0=1,x1=1,y1=1) 

x=seq(xi1,up,length=1000)
y1=(x/xi1)^(-gamma1)
polygon(c(1,x,up),c(0,y1,0), density=50,angle=90,col="red")
x2=seq(0,1,length=100)
y2=rep(1,length=100)
polygon(c(0,x2,1),c(0,y2,0), density=50,angle=90,col="red")
abline(v=2*xi1,col="blue")

Mean=expression(paste("Mean =",integral(S(x),0,infinity),dx==infinity))
text(10,0.3,Mean,cex=1,col="red")

#-------------------
# Figure 2
#-------------------
par(mfrow=c(1,2))
data<-read.csv("Book1.csv") ## set the directry

x=data$Age 
h1=hazard(data$White.Male)
h2=hazard(data$White.Female)
h3=hazard(data$Black.Male)
h4=hazard(data$Black.Female)

hazard<-function(s)1-s[-1]/s[-length(s)]

plot( c(0,85), c(0,0.12), type="n",xlab = "Age (year)",ylab = "Hazard function",las=1 )
lines(x[-1],h1,lty=1,col=1)
lines(x[-1],h2,lty=3,col=2)
lines(x[-1],h3,lty=2,col=3)
lines(x[-1],h4,lty=5,col=4)

legend(0,0.10,c("White male","White female","Black male","Black female"),
       lty=c(1,3,2,5),col=1:4,bty="n")

### Age 1-12
plot(c(0,12),c(-9,-4),type="n",xlab="Age (year)",
     ylab="ln( hazard function )",las=1)
lines(x[-1][1:12],log(h1[1:12]),lty=1,col=1)
lines(x[-1][1:12],log(h2[1:12]),lty = 3,col=2)
lines(x[-1][1:12],log(h3[1:12]),lty = 2,col=3)
lines(x[-1][1:12],log(h4[1:12]),lty = 5,col=4)

legend(4,-5,c("White male","White female","Black male","Black female"),
       lty=c(1,3,2,5),col=1:4,bty="n")

#-------------------
# Figure 3: hazard function of Weibull distribution
#-------------------
plot(c(0,10),c(0,1),type="n",xlab="Time",ylab="Weibull hazard function",las=1)

x <- seq(0,10,by=0.01)
h <- function(a,b){a*b*(x^(a-1))}
lines(x,h(a=.5,b=.2),lty=1,lwd=2,col=1)
lines(x,h(a=1,b=.1),lty=3,lwd=1,col=2)
lines(x,h(a=2,b=.05),lty=2,lwd=1,col=4)
lines(x,h(a=5,b=.02),lty=4,lwd=1,col=6)

Legend=c(expression(paste(alpha," = 0.5    ",lambda," = 0.2")),
         expression(paste(alpha," = 1      ",lambda," = 0.1")),
         expression(paste(alpha," = 2      ",lambda," = 0.05")),
         expression(paste(alpha," = 5      ",lambda," = 0.02")))
legend(1.5,1,legend=Legend,lty=c(1,3,2,4),lwd=c(2,1,1,1),col=c(1,2,4,6),bty="n")

h.Weib=expression(paste("h(x) =",alpha,lambda,x^{alpha-1}))
text(6,0.3,h.Weib,cex=1)

par(mfrow=c(1,1))



#-------------------
# Figure 4: hazard function of log-normal distribution
#-------------------
mu=c(0,0,0,0)
s=c(1,2,3,5)
len_m=length(mu)
cols=c(1,2,4,6)
ltys=c(1,3,2,4)

plot(x=-1,y=-1,xlim=c(0,2.5),ylim=c(0,1.6),
     xlab="Time",ylab="Lognormal hazard function")
par(new=F)

x=seq(0.00001,2.5,length=10000)
for (i in 1:length(mu)) {
  z=(log(x)-mu[i])/s[i]
  p=pnorm(z,0,1)
  h=exp(-z^2/2)/(x*s[i]*sqrt(2*pi)*(1-p))
  lines(x,h,ann=F,lty=ltys[i],col=cols[i])
  par(new=T)
}
Legend=c(expression(paste(mu," = 0,  ",sigma," = 1")),
         expression(paste(mu," = 0,  ",sigma," = 2")),
         expression(paste(mu," = 0,  ",sigma," = 3")),
        expression(paste(mu," = 0,  ",sigma," = 4")))

legend("top",legend=Legend,
       lty =c(1,3,2,4),lwd=c(1,1,1,1),col=c(1,2,4,6),bty="n")


#-------------------
# Figure 5: hazard function of log-logistic distribution
#-------------------
x<-(0:500)/100
lam=1;a=3;
lam1=1;a1=2
lam2=1;a2=1
lam3=1;a3=0.5

h<-(a*(x^(a-1))*lam)/(1+lam*(x^a))
h1<-(a1*(x^(a1-1))*lam1)/(1+lam1*(x^a1))
h2<-(a2*(x^(a2-1))*lam2)/(1+lam2*(x^a2))
h3<-(a3*(x^(a3-1))*lam3)/(1+lam3*(x^a3))

Mode=((a-1)/lam)^(1/a);H=h[sum(x<=Mode)]
Mode1=((a1-1)/lam1)^(1/a1);H1=h1[sum(x<=Mode1)]
Mode2=((a2-1)/lam2)^(1/a2);H2=h2[sum(x<=Mode2)]

plot(c(0,5),c(0,2),type="n",xlab="Time",
     ylab="Log-logistic hazard function",las=1)  
lines(x,h,col=1);points(Mode,H,col=1)
lines(x,h1,lty=3,lwd=1,col=2);points(Mode1,H1,col=2)
lines(x,h2,lty=2,lwd=1,col=4);points(Mode2,H2,col=4)
lines(x,h3,lty=4,lwd=1,col=6)

Legend=c(expression(paste(lambda," = 1,   ",alpha," = 3")),
         expression(paste(lambda," = 1,   ",alpha," = 2")),
         expression(paste(lambda," = 1,   ",alpha," = 1")),
         expression(paste(lambda," = 1,   ",alpha," = 0.5")))

legend(2,2,legend=Legend,lty=c(1,3,2,4),lwd=c(1,1,1),col=c(1,2,4,6),bty="n")

#-------------------
# Figure 6: hazard function of Gamma distribution
#-------------------
x<-(0:500)/100
lam<-1;beta<-2
lam1<-1;beta1<-1
lam2<-1;beta2<-0.5
lam3<-1;beta3<-0.1

f<-((lam^beta)*(x^(beta-1))*exp((-lam)*x))/gamma(beta)
s<-1-pgamma(lam*x,beta)
h<-f/s

f1<-((lam1^beta1)*(x^(beta1-1))*exp((-lam1)*x))/gamma(beta1)
s1<-1-pgamma(lam1*x,beta1)
h1<-f1/s1

f2<-((lam2^beta2)*(x^(beta2-1))*exp((-lam2)*x))/gamma(beta2)
s2<-1-pgamma(lam2*x,beta2)
h2<-f2/s2

f3<-((lam3^beta3)*(x^(beta3-1))*exp((-lam3)*x))/gamma(beta3)
s3<-1-pgamma(lam3*x,beta3)
h3<-f3/s3

plot(c(0,4),c(0,3),type="n",xlab="Time",ylab="Gamma hazard function",las=1)  
lines(x,h,lwd=1,col=1)
lines(x,h1,lty=3,lwd=1,col=2)
lines(x,h2,lty=4,lwd=1,col=4)
lines(x,h3,lty=5,lwd=1,col=6)

Legend=c(expression(paste(lambda," = 1,   ",beta," = 2")),
         expression(paste(lambda," = 1,   ",beta," = 1")),
         expression(paste(lambda," = 1,   ",beta," = 0.5")),
         expression(paste(lambda," = 1,   ",beta," = 0.1")))

legend(2,3,legend=Legend,lty=c(1,3,4,5),lwd=c(1,1,1,1),col=c(1,2,4,6),bty="n")

#-------------------
# Figure 7: hazard function by spline
#-------------------
#install.packages("joint.Cox")
library(joint.Cox)

lower=0
upper=9108 # maximum follow-up date
tvec=seq(lower,upper,length.out=500)

h.func=function(x){
  as.numeric(M.spline(x,lower,upper)%*%(h))
}

### hazard (spline) ###

h=c(0.20, 0.39, 0.20, 0.42, 0.24)
## Check the condition
0>=4*h[1]-3*h[2]+h[3]
0>=h[2]-2*h[3]+h[4]
0>=h[3]-3*h[4]+4*h[5]

### estimated hazard (spline) ###
plot(tvec,sapply(tvec,h.func),lwd=2,ylim=c(0,0.00021),
     xlab="Time (day)",ylab="Spline hazard function",
     xlim=c(lower,upper),type="l",lty="dotted",col="blue")

h=c(0.05, 0.38, 0.37, 0.09, 0.00) 
## Check the condition
0>=4*h[1]-3*h[2]+h[3]
0>=h[2]-2*h[3]+h[4]
0>=h[3]-3*h[4]+4*h[5]

### estimated hazard (spline) ###
points(tvec,sapply(tvec,h.func),lwd=2,type="l",col="red")
#lnames=c("h1=0.20, h2=0.39, h3=0.20, h4=0.42, h5=0.24",
#         "h1=0.05, h2=0.38, h3=0.37, h4=0.09, h5=0.00")

h1=expression(paste(h[1]," = 0.20, ",
                 h[2]," = 0.39, ",
                 h[3]," = 0.20, ",
                 h[4]," = 0.42, ",
                 h[5]," = 0.24"))
h2=expression(paste(h[1]," = 0.05, ",
                 h[2]," = 0.38, ",
                 h[3]," = 0.37, ",
                 h[4]," = 0.09, ",
                 h[5]," = 0.00"))
legend("top",h1,lwd=2,lty="dotted",col="blue",cex=1,bty="n",text.col="blue")
legend("bottom",h2,lwd=2,lty="solid",col="red",cex=1,bty="n",text.col="red")



#### Data Analysis

library(survival)

x=c(1641,5556,5421,3168,1534,
    6367,9460,6679,6142,5995,
    3953,6922,4210,5161,4732)
n=length(x)

plot(survfit(Surv(x,rep(1,n))~1),conf.int=FALSE,
     xlab="Time (hours)",ylab="Survival probability")
xx=seq(1,10000,length=100)

## Exponential
lambda=1/mean(x)
Exp.surv=function(x){exp(-lambda*x)}
points(x=xx,y=Exp.surv(xx),ylim=c(0,1),type="l",
       col="red",lty=2)
logL.Exp=n*log(lambda)-lambda*sum(x)

## Weibull
l.Weib=function(theta){
  lambda=exp(theta[1])
  a=exp(theta[2])
  l=n*log(lambda)+n*log(a)+(a-1)*sum(log(x))-lambda*sum(x^a)
  -l
}
res.Weib=nlm(l.Weib,p=c(0,0))
lambda=exp(res.Weib$estimate[1])
a=exp(res.Weib$estimate[2])
Weib.surv=function(x){exp(-lambda*x^a)}
points(x=xx,y=Weib.surv(xx),ylim=c(0,1),type="l",
       col="blue",lty=3)
logL.Weib=-res.Weib$minimum

## Lognormal
mu=mean(log(x))
sig=sd(log(x))
logL.LN=-n*log(2*pi*sig^2)/2-sum(log(x))-sum((log(x)-mu)^2)/2/sig^2
LN.surv=function(x){1-pnorm((log(x)-mu)/sig)}
points(x=xx,y=LN.surv(xx),ylim=c(0,1),type="l",
       col="darkgreen",lty=4)

## Pareto I
lambda=1/min(x)
a=n/sum(log(x/min(x)))
logL.Pareto=n*log(a)-n*a*log(lambda)-(a+1)*sum(log(x))
Pareto.surv=function(x){(lambda*x)^(-a)}
points(x=xx[xx>=min(x)],y=Pareto.surv(xx[xx>=min(x)]),
       ylim=c(0,1),type="l",col="orange",lty=5)

logL=c(logL.Exp,logL.Weib,logL.LN,logL.Pareto)
DF=c(1,2,2,2)
AIC=round(-2*logL+2*DF,1)
#### Summary
legend("topright",
       legend=c("Empirical",
                paste("Exponential, AIC=",AIC[1]),
                paste("Weibull, AIC=",AIC[2]),
                paste("Lognormal, AIC=",AIC[3]),
                paste("Pareto I, AIC=",AIC[4])),
       lty = c(1,2,3,4,5), lwd=c(1,1,1,1,1),bty="n",
       col=c("black","red","blue","darkgreen","orange"),
       text.col=c("black","red","blue","darkgreen","orange")
)

Nam=c("Exponential","Weibull","Lognormal")

Nam
logL






